@@ -26,11 +26,11 @@ Lavoco::Web::Editor - FastCGI app to edit flat-files.
 
 =head1 VERSION
 
-Version 0.04
+Version 0.05
 
 =cut
 
-our $VERSION = '0.04';
+our $VERSION = '0.05';
 
 $VERSION = eval $VERSION;
 
@@ -61,13 +61,13 @@ Creates a new instance of the editor object.
 =cut
 
 has  processes => ( is => 'rw', isa => 'Int',  default => 5         );
-has  base      => ( is => 'rw', isa => 'Str',  lazy => 1, builder => '_build_base'      );
+has _base      => ( is => 'rw', isa => 'Str',  lazy => 1, builder => '_build__base'     );
 has _pid       => ( is => 'rw', isa => 'Str',  lazy => 1, builder => '_build__pid'      );
 has _socket    => ( is => 'rw', isa => 'Str',  lazy => 1, builder => '_build__socket'   );
 has  filename  => ( is => 'rw', isa => 'Str',  lazy => 1, builder => '_build_filename'  );
 has  config    => ( is => 'rw', isa => 'HashRef' );
 
-sub _build_base
+sub _build__base
 {
     return $Bin;
 }
@@ -76,27 +76,23 @@ sub _build__pid
 {
     my $self = shift;
 
-    return $self->base . '/editor.pid';
+    return $self->_base . '/editor.pid';
 }
 
 sub _build__socket
 {
     my $self = shift;
 
-    return $self->base . '/editor.sock';
+    return $self->_base . '/editor.sock';
 }
 
 sub _build_filename
 {
     my $self = shift;
 
-    return $self->base . '/editor.json';
+    return $self->_base . '/editor.json';
 }
 
-=head3 base
-
-The base directory of the application, using L<FindBin>.
-
 =head3 processes
 
 Number of FastCGI process to spawn, 5 by default.
@@ -152,7 +148,7 @@ sub _init
 
     printf( "%-50s", "Checking logs directory");
 
-    my $log_dir = $self->base . '/logs';
+    my $log_dir = $self->_base . '/logs';
 
     if ( ! -e $log_dir || ! -d $log_dir )
     {
@@ -313,8 +309,6 @@ The editor app should be a simple Perl script in a folder with the following str
  
 The config file is read for each and every request, so you can reasonably enable editing of the editors own config file.
 
-The config file should be placed in the C<base> directory of your editor application.
-
 See the C<examples> directory for a sample JSON config file, similar to the following...
 
  {
@@ -330,7 +324,7 @@ See the C<examples> directory for a sample JSON config file, similar to the foll
      "salt"     : "abc123"
  }
 
-Two fields which drive the editor are C<folders> and C<files>, each of which is an array of paths, all relative to C<$editor-E<gt>base>.
+Two fields which drive the editor are C<folders> and C<files>, each of which is an array of paths, all relative to the base directory of the editor script.
 
 All visible files in the C<folders> are editable, but not sub-directories, you need to add those separately.  The editor can also create new files in each folder.
 
@@ -365,7 +359,7 @@ sub _handler
             started  => join( '.', gettimeofday ),
         );
 
-        my $log = Log::AutoDump->new( base_dir => $stash{ app }->base . '/logs', filename => 'editor.log' );
+        my $log = Log::AutoDump->new( base_dir => $stash{ app }->_base . '/logs', filename => 'editor.log' );
 
         $log->debug("Started");
 
@@ -433,7 +427,7 @@ sub _handler
 
                     $log->debug( "Processing folder: " . $folder );
 
-                    my $path = $stash{ app }->base . '/' . $folder;
+                    my $path = $stash{ app }->_base . '/' . $folder;
 
                     if ( -d $path )
                     {
@@ -441,7 +435,7 @@ sub _handler
 
                         opendir( my $dh, $path ) || $log->debug("Can't opendir $path: $!");
 
-                        push @{ $folder{ files } }, sort { $a cmp $b } grep { ! -d ( $stash{ app }->base . '/' . $folder . '/' . $_ ) } grep { $_ !~ /^\./ } readdir( $dh );
+                        push @{ $folder{ files } }, sort { $a cmp $b } grep { ! -d ( $stash{ app }->_base . '/' . $folder . '/' . $_ ) } grep { $_ !~ /^\./ } readdir( $dh );
 
                         closedir( $dh );
 
@@ -463,7 +457,7 @@ sub _handler
 
                     $log->debug( "Processing file: " . $file );
 
-                    my $path = $stash{ app }->base . '/' . $file;
+                    my $path = $stash{ app }->_base . '/' . $file;
 
                     if ( -f $path )
                     {
@@ -496,16 +490,16 @@ sub _handler
 
                             if ( ! exists $req->parameters->{ content } )
                             {
-                                $log->debug( "Reading content of " . $stash{ app }->base . '/' . $folder->{ path } . '/' . $file );
+                                $log->debug( "Reading content of " . $stash{ app }->_base . '/' . $folder->{ path } . '/' . $file );
 
-                                $stash{ content } = read_file( $stash{ app }->base . '/' . $folder->{ path } . '/' . $file, { binmode => ':utf8' } );
+                                $stash{ content } = read_file( $stash{ app }->_base . '/' . $folder->{ path } . '/' . $file, { binmode => ':utf8' } );
                             }
                         }
                     }
 
                     if ( exists $req->parameters->{ content } )
                     {
-                        write_file( $stash{ app }->base . '/' . $folder->{ path } . '/' . $req->parameters->{ file }, { binmode => ':utf8' }, $req->parameters->{ content } );
+                        write_file( $stash{ app }->_base . '/' . $folder->{ path } . '/' . $req->parameters->{ file }, { binmode => ':utf8' }, $req->parameters->{ content } );
 
                         $stash{ file } = $req->parameters->{ file };
 
@@ -525,13 +519,13 @@ sub _handler
 
                     if ( ! exists $req->parameters->{ content } )
                     {
-                        $log->debug( "Reading content of " . $stash{ app }->base .  '/' . $file );
+                        $log->debug( "Reading content of " . $stash{ app }->_base .  '/' . $file );
 
-                        $stash{ content } = read_file( $stash{ app }->base . '/' . $file, { binmode => ':utf8' } );
+                        $stash{ content } = read_file( $stash{ app }->_base . '/' . $file, { binmode => ':utf8' } );
                     }
                     else
                     {
-                        write_file( $stash{ app }->base . '/' . $file, { binmode => ':utf8' }, $req->parameters->{ content } );
+                        write_file( $stash{ app }->_base . '/' . $file, { binmode => ':utf8' }, $req->parameters->{ content } );
 
                         $stash{ file } = $req->parameters->{ file };
 
